.table-card {
    .list-header {
        box-sizing: border-box;
        display: flex;
        height: 64px;
        justify-content: space-between;
        padding: 8px 16px 8px 22px;

        h4 {
            font-family: 'Roboto', 'Noto', sans-serif;
            font-size: 20px;
            font-weight: 500;
            height: 32px;
            letter-spacing: calc(0.02 * 16px);
            line-height: 32px;
            margin: 8px 0;
            overflow: hidden;
            text-decoration: inherit;
            text-overflow: ellipsis;
            text-transform: inherit;
            white-space: nowrap;

            -webkit-font-smoothing: antialiased;
        }
    }

    table {
        border-collapse: collapse;
        border-spacing: 0;
        text-align: left;
        width: 100%;

        thead {
            tr {
                color: rgba(0,0,0,0.54);
                font-size: 12px;
                height: 56px;
                line-height: 56px;

                th {
                    font-weight: normal;
                    padding-bottom: 0;
                    padding-top: 0;
                }
            }
        }

        tbody {
            color: rgba(0,0,0,0.87);
            font-size: 13px;
            height: 48px;
            line-height: 48px;

            tr {
                border-top: 1px solid #E0E0E0;
                box-sizing: border-box;
                cursor: pointer;

                td {
                    box-sizing: border-box;
                    height: 48px;
                    line-height: 18px;
                    padding-bottom: 15px;
                    padding-top: 15px;

                    &.boolean {
                        color: rgba(0,0,0,0.38);

                        &.true {
                            color: #0185D3;
                        }

                        .material-icons {
                            display: flex;
                            font-size: 18px;
                            font-weight: bold;
                            justify-content: center;
                            line-height: 18px;
                            height: 18px;
                        }
                    }
                }
            }
        }

        th,
        td {
            padding-left: 56px;
            padding-right: 0;
            position: relative;

            & > span {
                display: block;
                height: 18px;
                overflow: hidden;
                position: absolute;
                text-overflow: ellipsis;
                top: 15px;
                white-space: nowrap;
                width: calc(100% - 56px);
            }

            &:first-child {
                padding-left: 24px;
                padding-right: 0;

                & > span {
                    width: calc(100% - 24px);
                }
            }

            &:last-child {
                padding-left: 56px;
                padding-right: 24px;

                & > span {
                    width: calc(100% - 80px);
                }
            }
        }
    }

    .table-pagination {
        border-top: 1px solid #E0E0E0;
        color: rgba(0,0,0,0.54);
        display: flex;
        font-size: 0;
        height: 56px;
        justify-content: flex-end;
        line-height: 56px;
        padding: 0 2px 0 24px;

        .current-range {
            font-size: 12px;
            padding-right: 20px;
        }

        .btn {  // Shim; to be removed when we integrate Immaterial styles.
            background: transparent;
            border: none;
            display: inline-block;
            font-size: 14px;
            height: 36px;
            letter-spacing: calc(0.04 * 16px);
            line-height: 24px;
            text-decoration: none;
            text-transform: uppercase;
            user-select: none;
        }

        .btn {
            border-radius: 18px;
            margin: 10px 6px;
            min-width: 36px;
            padding: 6px;
            width: 36px;

            &.disabled {
                color: rgba(0,0,0,0.18);

                &:hover {
                    pointer-events: none;

                    &::before,
                    &::after {
                        display: none;
                    }
                }
            }
        }
    }
}
