<!DOCTYPE html>
<html>
  <head>
    <meta charset="utf-8">
    <title></title>
  </head>
  <body>
      <script src="/js/main-headlines.js"></script>
      <input id="drp1" type="text" size="30" value="">
      <script type="text/javascript">
          window.jjj(document).ready(function() {
              window.jjj('#drp1').dateRangePicker();
          });
      </script>
  </body>
</html>