# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2016-06-27 15:06
from __future__ import unicode_literals

import budget.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('budget', '0012_merge'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='package',
            options={},
        ),
        migrations.AlterField(
            model_name='package',
            name='hub',
            field=models.CharField(max_length=100, validators=[budget.validators.hub_exists]),
        ),
    ]
